@@ -4,6 +4,7 @@ use heron::*;
 
 fn main() {
     App::build()
+        .insert_resource(Gravity::from(Vec3::new(0., -98.1, 0.)))
         .add_plugins(DefaultPlugins)
         .add_plugin(PhysicsPlugin::default()) // Add the plugin
         .add_startup_system(spawn.system())
@@ -17,7 +18,7 @@ fn spawn(mut commands: Commands) {
     commands
         .spawn_bundle((Transform::default(), GlobalTransform::default()))
         .insert(CollisionShape::Sphere { radius: 50.0 })
-        .insert(RigidBody::Static);
+        .insert(RigidBody::Sensor);
 
     // Cuboid
     commands
@@ -29,7 +30,7 @@ fn spawn(mut commands: Commands) {
             half_extends: Vec2::new(50.0, 50.0).extend(0.0),
             border_radius: None,
         })
-        .insert(RigidBody::Static);
+        .insert(RigidBody::KinematicVelocityBased);
 
     // Capsule
     commands
@@ -41,9 +42,9 @@ fn spawn(mut commands: Commands) {
             radius: 50.0,
             half_segment: 50.0,
         })
-        .insert(RigidBody::Static);
+        .insert(RigidBody::KinematicPositionBased);
 
-    // ConvexHull, in this case describing a triangle
+    // ConvexHull, a random quadrilateral
     commands
         .spawn_bundle((
             Transform::from_translation(Vec3::Y * 150.0),
@@ -54,10 +55,11 @@ fn spawn(mut commands: Commands) {
                 Vec3::new(0.0, -50.0, 0.0),
                 Vec3::new(50.0, 0.0, 0.0),
                 Vec3::new(-50.0, 0.0, 0.0),
+                Vec3::new(5.0, 10.0, 0.0),
             ],
             border_radius: None,
         })
-        .insert(RigidBody::Static);
+        .insert(RigidBody::Dynamic);
 
     // Height field
     commands
